searchNodes=[{"ref":"Dataset.html","title":"Dataset","module":"Dataset","type":"module","doc":"Datasets represent labeled tabular data. Datasets are enumerable: iex&gt; Dataset.new([{:a, :b, :c}, ...&gt; {:A, :B, :C}, ...&gt; {:i, :ii, :iii}, ...&gt; {:I, :II, :III}], ...&gt; {&quot;one&quot;, &quot;two&quot;, &quot;three&quot;}) ...&gt; |&gt; Enum.map(&amp;elem(&amp;1, 2)) [:c, :C, :iii, :III] Datasets are also collectable: iex&gt; for x &lt;- 0..10, into: Dataset.empty({:n}), do: x %Dataset{labels: {:n}, rows: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]}"},{"ref":"Dataset.html#empty/1","title":"Dataset.empty/1","module":"Dataset","type":"function","doc":"Return a dataset with no rows and labels specified by the tuple passed as label. If label is not specified, return an empty dataset with zero columns."},{"ref":"Dataset.html#inner_join/5","title":"Dataset.inner_join/5","module":"Dataset","type":"function","doc":"Return the result of performing an inner join on datasets ds1 and ds2, using k1 and k2 as the key labels on each respective dataset. The returned dataset will contain columns for each label specified in out_labels, which is a keyword list of the form [left_or_right: label, ...]. iex&gt; iso_countries = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;us&quot;, &quot;United States&quot;}, ...&gt; {&quot;uk&quot;, &quot;United Kingdom&quot;}, ...&gt; {&quot;ca&quot;, &quot;Canada&quot;}, ...&gt; {&quot;de&quot;, &quot;Germany&quot;}, ...&gt; {&quot;nl&quot;, &quot;Netherlands&quot;}, ...&gt; {&quot;sg&quot;, &quot;Singapore&quot;} ...&gt; ], ...&gt; {:iso_country, :country_name} ...&gt; ) ...&gt; ...&gt; country_clicks = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;United States&quot;, &quot;13&quot;}, ...&gt; {&quot;United Kingdom&quot;, &quot;11&quot;}, ...&gt; {&quot;Canada&quot;, &quot;4&quot;}, ...&gt; {&quot;Germany&quot;, &quot;4&quot;}, ...&gt; {&quot;France&quot;, &quot;2&quot;} ...&gt; ], ...&gt; {:country_name, :clicks} ...&gt; ) ...&gt; ...&gt; Dataset.inner_join(country_clicks, iso_countries, :country_name, ...&gt; right: :iso_country, ...&gt; left: :clicks ...&gt; ) %Dataset{ labels: {:iso_country, :clicks}, rows: [{&quot;ca&quot;, &quot;4&quot;}, {&quot;de&quot;, &quot;4&quot;}, {&quot;uk&quot;, &quot;11&quot;}, {&quot;us&quot;, &quot;13&quot;}] }"},{"ref":"Dataset.html#left_join/5","title":"Dataset.left_join/5","module":"Dataset","type":"function","doc":"Return the result of performing a left join on datasets ds1 and ds2, using k1 and k2 as the key labels on each respective dataset. The returned dataset will contain columns for each label specified in out_labels, which is a keyword list of the form [left_or_right: label, ...]. iex&gt; iso_countries = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;us&quot;, &quot;United States&quot;}, ...&gt; {&quot;uk&quot;, &quot;United Kingdom&quot;}, ...&gt; {&quot;ca&quot;, &quot;Canada&quot;}, ...&gt; {&quot;de&quot;, &quot;Germany&quot;}, ...&gt; {&quot;nl&quot;, &quot;Netherlands&quot;}, ...&gt; {&quot;sg&quot;, &quot;Singapore&quot;} ...&gt; ], ...&gt; {:iso_country, :country_name} ...&gt; ) ...&gt; ...&gt; country_clicks = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;United States&quot;, &quot;13&quot;}, ...&gt; {&quot;United Kingdom&quot;, &quot;11&quot;}, ...&gt; {&quot;Canada&quot;, &quot;4&quot;}, ...&gt; {&quot;Germany&quot;, &quot;4&quot;}, ...&gt; {&quot;France&quot;, &quot;2&quot;} ...&gt; ], ...&gt; {:country_name, :clicks} ...&gt; ) ...&gt; ...&gt; Dataset.left_join(country_clicks, iso_countries, :country_name, ...&gt; right: :iso_country, ...&gt; left: :clicks ...&gt; ) %Dataset{ labels: {:iso_country, :clicks}, rows: [{&quot;ca&quot;, &quot;4&quot;}, {nil, &quot;2&quot;}, {&quot;de&quot;, &quot;4&quot;}, {&quot;uk&quot;, &quot;11&quot;}, {&quot;us&quot;, &quot;13&quot;}] }"},{"ref":"Dataset.html#new/2","title":"Dataset.new/2","module":"Dataset","type":"function","doc":"Construct a new dataset. A dataset is a list of tuples. With no arguments, an empty dataset with zero columns is constructed. Withf one argument a dataset is constructed with the passed object interpreted as rows and labels beginning with 0 are generated, the number of which are determined by size of the first tuple in the data. iex&gt; Dataset.new() %Dataset{rows: [], labels: {}} iex&gt; Dataset.new([{:foo, :bar}, {:eggs, :ham}]) %Dataset{rows: [foo: :bar, eggs: :ham], labels: {0, 1}} iex&gt; Dataset.new([{0,0}, {1, 1}, {2, 4}, {3, 9}], ...&gt; {:x, :x_squared}) %Dataset{labels: {:x, :x_squared}, rows: [{0, 0}, {1, 1}, {2, 4}, {3, 9}]}"},{"ref":"Dataset.html#outer_join/5","title":"Dataset.outer_join/5","module":"Dataset","type":"function","doc":"Return the result of performing an outer join on datasets ds1 and ds2, using k1 and k2 as the key labels on each respective dataset. The returned dataset will contain columns for each label specified in out_labels, which is a keyword list of the form [left_or_right: label, ...]. iex&gt; iso_countries = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;us&quot;, &quot;United States&quot;}, ...&gt; {&quot;uk&quot;, &quot;United Kingdom&quot;}, ...&gt; {&quot;ca&quot;, &quot;Canada&quot;}, ...&gt; {&quot;de&quot;, &quot;Germany&quot;}, ...&gt; {&quot;nl&quot;, &quot;Netherlands&quot;}, ...&gt; {&quot;sg&quot;, &quot;Singapore&quot;} ...&gt; ], ...&gt; {:iso_country, :country_name} ...&gt; ) ...&gt; ...&gt; country_clicks = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;United States&quot;, &quot;13&quot;}, ...&gt; {&quot;United Kingdom&quot;, &quot;11&quot;}, ...&gt; {&quot;Canada&quot;, &quot;4&quot;}, ...&gt; {&quot;Germany&quot;, &quot;4&quot;}, ...&gt; {&quot;France&quot;, &quot;2&quot;} ...&gt; ], ...&gt; {:country_name, :clicks} ...&gt; ) ...&gt; ...&gt; Dataset.outer_join(country_clicks, iso_countries, :country_name, ...&gt; right: :iso_country, ...&gt; left: :clicks ...&gt; ) %Dataset{ labels: {:iso_country, :clicks}, rows: [ {&quot;ca&quot;, &quot;4&quot;}, {nil, &quot;2&quot;}, {&quot;de&quot;, &quot;4&quot;}, {&quot;nl&quot;, nil}, {&quot;sg&quot;, nil}, {&quot;uk&quot;, &quot;11&quot;}, {&quot;us&quot;, &quot;13&quot;} ] }"},{"ref":"Dataset.html#right_join/5","title":"Dataset.right_join/5","module":"Dataset","type":"function","doc":"Return the result of performing a right join on datasets ds1 and ds2, using k1 and k2 as the key labels on each respective dataset. The returned dataset will contain columns for each label specified in out_labels, which is a keyword list of the form [left_or_right: label, ...]. iex&gt; iso_countries = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;us&quot;, &quot;United States&quot;}, ...&gt; {&quot;uk&quot;, &quot;United Kingdom&quot;}, ...&gt; {&quot;ca&quot;, &quot;Canada&quot;}, ...&gt; {&quot;de&quot;, &quot;Germany&quot;}, ...&gt; {&quot;nl&quot;, &quot;Netherlands&quot;}, ...&gt; {&quot;sg&quot;, &quot;Singapore&quot;} ...&gt; ], ...&gt; {:iso_country, :country_name} ...&gt; ) ...&gt; ...&gt; country_clicks = ...&gt; Dataset.new( ...&gt; [ ...&gt; {&quot;United States&quot;, &quot;13&quot;}, ...&gt; {&quot;United Kingdom&quot;, &quot;11&quot;}, ...&gt; {&quot;Canada&quot;, &quot;4&quot;}, ...&gt; {&quot;Germany&quot;, &quot;4&quot;}, ...&gt; {&quot;France&quot;, &quot;2&quot;} ...&gt; ], ...&gt; {:country_name, :clicks} ...&gt; ) ...&gt; ...&gt; Dataset.right_join(country_clicks, iso_countries, :country_name, ...&gt; right: :iso_country, ...&gt; left: :clicks ...&gt; ) %Dataset{ labels: {:iso_country, :clicks}, rows: [ {&quot;ca&quot;, &quot;4&quot;}, {&quot;de&quot;, &quot;4&quot;}, {&quot;nl&quot;, nil}, {&quot;sg&quot;, nil}, {&quot;uk&quot;, &quot;11&quot;}, {&quot;us&quot;, &quot;13&quot;} ] }"},{"ref":"Dataset.html#rotate/1","title":"Dataset.rotate/1","module":"Dataset","type":"function","doc":"Returns a dataset with each value in row i and column j transposed into row j and column i. The dataset is labelled with integer indicies beginning with zero. iex&gt; Dataset.new([{:a,:b,:c}, ...&gt; {:A, :B, :C}, ...&gt; {:i, :ii, :iii}, ...&gt; {:I, :II, :III}]) ...&gt; |&gt; Dataset.rotate() %Dataset{ labels: {0, 1, 2, 3}, rows: [{:a, :A, :i, :I}, {:b, :B, :ii, :II}, {:c, :C, :iii, :III}] }"},{"ref":"Dataset.html#select/2","title":"Dataset.select/2","module":"Dataset","type":"function","doc":"Return a new dataset with columns chosen from the input dataset ds. iex&gt; Dataset.new([{:a,:b,:c}, ...&gt; {:A, :B, :C}, ...&gt; {:i, :ii, :iii}, ...&gt; {:I, :II, :III}], ...&gt; {&quot;first&quot;, &quot;second&quot;, &quot;third&quot;}) ...&gt; |&gt; Dataset.select([&quot;second&quot;]) %Dataset{rows: [{:b}, {:B}, {:ii}, {:II}], labels: {&quot;second&quot;}}"},{"ref":"Dataset.html#to_map_list/1","title":"Dataset.to_map_list/1","module":"Dataset","type":"function","doc":"Return the contents of _ds as a list of maps."}]